% ----
function [Zc,Gamma,ro,c0] = LossyTubeParams(dia,f,Temp)
%--------------------------------------------------------------------------
% Modified from keefe.m by jba Mar 30, 2013
%
% Calculate cavity model parameters.
% Usage: [Zc,Gamma,ro] = keefe(dia,f,Temp);
%
% Input parameters:
%
% dia: tube dia in mm
% f: frequency vector
% Temp: Temperature
%
% Output parameters:
%
% Zc: lossy characteristic impedance (complex function of frequency)
% Gamma: lossy propagation function [1/mm] (complex function of freq)
% ro: surge resistance (a real number)
% c: speed of sound
%
% Keefe, JASA, Vol.75 No.1, Jan. 1984 (Pg. 58-62)
% a JBA creation...modified 5/2/00 by Tony Miller
% all cgs units
% vectorized with respect to length len of size(1,number_of_cavities), pb may-2001
% input lenght 'len' in mm
% impedance is normalized to tube characteristic impedance without loss
%--------------------------------------------------------------------------

   w = 2*pi*f;			         % radians
   radius = dia/20; 	       % mm to cm
   dt = (Temp-27);       % degrees C

   area = pi*(radius)^2;     		    % cm^2

   rho = (1-0.00335*dt)*1.1769e-3; % g/cm^3
   eta = (1+0.0025*dt)*1.846e-4; % g/(s*cm)
   c = (1+0.00166*dt)*3.4723e4; % cm/s

   rv = radius*sqrt(rho*w/eta); 	  % dimensionless
   ro = rho*c/area;             % surge resistance, jba's 

   Zor = ro*(1+0.369./rv);					% real(characteristic impedance)
   Zoi = -ro*(0.369./(rv) + 1.149./(rv.^2) +0.303./(rv.^3)); % imag(characteristic impedance)

   alpha = (w/c).*(1.045./(rv) + 1.08./(rv.^2) + 0.75./(rv.^3)); % real(propagation const)
   beta = (w/c).*(1+1.045./rv); % imag(propagation const)

   Zc = Zor + (i*Zoi);   % characteristic impedance of tube (with loss)
   gamma = alpha + (i*beta); % in 1/cm

   %Commented out by jba on Mar30, 2013
   %Zc = Zo(ones(n,1),1:nf); % normalized characteristic impedance of tube (with loss)

   Gamma=gamma/10; % in 1/mm
   
   c0=c/100;
   
   % change ro and Zc to mks units
   ro = ro * 1e5;
   Zc = Zc * 1e5;
   
return



